@@ -1,14 +1,12 @@
-package Regexp::Common::list;
+package Regexp::Common::list; {
+
 use strict;
-use warnings;
-no warnings 'syntax';
+local $^W = 1;
 
 use Regexp::Common qw /pattern clean no_defaults/;
 
-our $VERSION = 'v1.0.0'; # VERSION
-
 sub gen_list_pattern {
-    my ( $pat, $sep, $lsep ) = @_;
+    my ($pat, $sep, $lsep) = @_;
     $lsep = $sep unless defined $lsep;
     return "(?k:(?:(?:$pat)(?:$sep))*(?:$pat)(?k:$lsep)(?:$pat))";
 }
@@ -16,27 +14,25 @@ sub gen_list_pattern {
 my $defpat = '.*?\S';
 my $defsep = '\s*,\s*';
 
-pattern
-  name   => [ 'list', "-pat=$defpat", "-sep=$defsep", '-lastsep' ],
-  create => sub { gen_list_pattern( @{ $_[1] }{ -pat, -sep, -lastsep } ) },
-  ;
+pattern name   => ['list', "-pat=$defpat", "-sep=$defsep", '-lastsep'],
+        create => sub {gen_list_pattern (@{$_[1]}{-pat, -sep, -lastsep})},
+        ;
 
-pattern
-  name   => [ 'list', 'conj', '-word=(?:and|or)' ],
-  create => sub {
-    gen_list_pattern( $defpat, $defsep, '\s*,?\s*' . $_[1]->{-word} . '\s*' );
-  },
-  ;
+pattern name   => ['list', 'conj', '-word=(?:and|or)'],
+        create => sub {gen_list_pattern($defpat, $defsep,
+                                        '\s*,?\s*'.$_[1]->{-word}.'\s*');
+                  },
+        ;
 
-pattern
-  name   => [ 'list', 'and' ],
-  create => sub { gen_list_pattern( $defpat, $defsep, '\s*,?\s*and\s*' ) },
-  ;
+pattern name   => ['list', 'and'],
+        create => sub {gen_list_pattern ($defpat, $defsep, '\s*,?\s*and\s*')},
+        ;
 
-pattern
-  name   => [ 'list', 'or' ],
-  create => sub { gen_list_pattern( $defpat, $defsep, '\s*,?\s*or\s*' ) },
-  ;
+pattern name   => ['list', 'or'],
+        create => sub {gen_list_pattern ($defpat, $defsep, '\s*,?\s*or\s*')},
+        ;
+
+}
 
 1;
 
@@ -132,30 +128,24 @@ L<Regexp::Common> for a general description of how to use this interface.
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior <glasswalk3r@yahoo.com.br>
+Damian Conway (damian@conway.org)
 
-=head1 LICENSE and COPYRIGHT
+=head1 MAINTAINANCE
 
-This software is copyright (c) 2024 of Alceu Rodrigues de Freitas Junior,
-glasswalk3r at yahoo.com.br
+This package is maintained by Abigail S<(I<regexp-common@abigail.nl>)>.
 
-This file is part of regex-common project.
+=head1 BUGS AND IRRITATIONS
 
-regex-commonis free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation, either version 3 of the License, or (at your option) any later
-version.
+Bound to be plenty.
 
-regex-common is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-details.
+For a start, there are many common regexes missing.
+Send them in to I<regexp-common@abigail.nl>.
 
-You should have received a copy of the GNU General Public License along with
-regex-common. If not, see (http://www.gnu.org/licenses/).
+=head1 COPYRIGHT
 
-The original project [Regexp::Common](https://metacpan.org/pod/Regexp::Common)
-is licensed through the MIT License, copyright (c) Damian Conway
-(damian@cs.monash.edu.au) and Abigail (regexp-common@abigail.be).
+     Copyright (c) 2001 - 2002, Damian Conway. All Rights Reserved.
+       This module is free software. It may be used, redistributed
+      and/or modified under the terms of the Perl Artistic License
+            (see http://www.perl.com/perl/misc/Artistic.html)
 
 =cut
